@@ -103,8 +103,8 @@ class MMSDecoder(wsp_pdu.Decoder):
 			#print "MMS HEADER:", k, hdrlist[k]	
 			fp.write(str(k) + " " + str(hdrlist[k]) + "\n")
 		fp.close()
-        self.decodeMessageBodyToPath(bodyIter)
-        print self._mmsMessage.headers
+        self._mmsMessage.attachments = self.decodeMessageBodyToPath(bodyIter)
+        #print self._mmsMessage.headers
         return self._mmsMessage
     
     def decodeCustom(self, data):
@@ -329,6 +329,8 @@ class MMSDecoder(wsp_pdu.Decoder):
         nEntries = self.decodeUintvar(dataIter)
         #print 'Number of data entries (parts) in MMS body:', nEntries
         
+        attachments = []
+        
         ########## MMS body: entries ##########
         # For every data "part", we have to read the following sequence:
         # <length of content-type + other possible headers>,
@@ -399,7 +401,7 @@ class MMSDecoder(wsp_pdu.Decoder):
             if not os.path.isdir(dirname):
                 os.makedirs(dirname)
             filename = None
-            print "MMSBODY HEADERS:", headers
+            #print "MMSBODY HEADERS:", headers
             
             ### loop through the headers, if we find a "name" header
             ### using it seems like a good idea, right?
@@ -414,12 +416,13 @@ class MMSDecoder(wsp_pdu.Decoder):
 			pass
 
             
-            if filename != None:    
-                f = open(dirname + '/%s' % (filename), 'wb')
-            else:
-                f = open(dirname + '/part%d.%s' % (partNum, extension), 'wb')
+            if filename == None:    
+           	filename = str(partNum) + "." + str(extension)
+            f = open(dirname + '/%s' % (filename), 'wb')
             data.tofile(f)
             f.close()
+            attachments.append(filename)
+	return attachments
     
     @staticmethod
     def decodeHeader(byteIter):
